Utilities for working with definition references in expressions.
Functions
- contains_
ref - Check if expression contains a reference to the given name.
- ref_
names - Collect all reference names as owned strings.
- ref_
nodes - Iterate over all Ref nodes in an expression tree.