Semantic validation for the typed AST.
Checks constraints that are easier to express after parsing:
- Mixed tagged/untagged alternations
Semantic validation for the typed AST.
Checks constraints that are easier to express after parsing: