DiagnosticBuilder

Struct DiagnosticBuilder 

pub struct DiagnosticBuilder<'d> { /* private fields */ }

Implementations

Source

impl<'d> DiagnosticBuilder<'d>

pub fn message(self, msg: impl Into<String>) -> Self

Provide custom detail for this diagnostic, rendered using the kind’s template.

pub fn related_to( self, source: SourceId, range: TextRange, msg: impl Into<String>, ) -> Self

pub fn suppression_range(self, range: TextRange) -> Self

Set the suppression range for this diagnostic.

The suppression range is used to suppress cascading errors. Errors whose display range falls within another error’s suppression range may be suppressed if the containing error has higher priority.

Typically set to the parent context span (e.g., enclosing tree).

pub fn fix( self, description: impl Into<String>, replacement: impl Into<String>, ) -> Self

pub fn hint(self, hint: impl Into<String>) -> Self

pub fn emit(self)