pub struct NamedNode(/* private fields */);Implementations
Sourceimpl NamedNode
impl NamedNode
pub fn cast(node: SyntaxNode) -> Option<Self>
pub fn can_cast(kind: SyntaxKind) -> bool
pub fn as_cst(&self) -> &SyntaxNode
pub fn text_range(&self) -> TextRange
Sourceimpl NamedNode
impl NamedNode
pub fn node_type(&self) -> Option<SyntaxToken>
Sourcepub fn is_any(&self) -> bool
pub fn is_any(&self) -> bool
Returns true if the node type is wildcard (_), matching any named node.
Sourcepub fn is_missing(&self) -> bool
pub fn is_missing(&self) -> bool
Returns true if this is a MISSING node: (MISSING ...).
Sourcepub fn missing_constraint(&self) -> Option<SyntaxToken>
pub fn missing_constraint(&self) -> Option<SyntaxToken>
For MISSING nodes, returns the inner type constraint if present.
(MISSING identifier) → Some(“identifier”)
(MISSING ";") → Some(“;”)
(MISSING) → None
pub fn children(&self) -> impl Iterator<Item = Expr> + '_
Sourcepub fn items(&self) -> impl Iterator<Item = SeqItem> + '_
pub fn items(&self) -> impl Iterator<Item = SeqItem> + '_
Returns children interleaved with anchors, preserving order.
Sourcepub fn predicate(&self) -> Option<NodePredicate>
pub fn predicate(&self) -> Option<NodePredicate>
Returns the predicate if present: (identifier == "foo").