NodePredicate

Struct NodePredicate 

pub struct NodePredicate(/* private fields */);

Implementations

Source

impl NodePredicate

pub fn cast(node: SyntaxNode) -> Option<Self>

pub fn can_cast(kind: SyntaxKind) -> bool

pub fn as_cst(&self) -> &SyntaxNode

pub fn text_range(&self) -> TextRange

Source

impl NodePredicate

pub fn operator_token(&self) -> Option<SyntaxToken>

Returns the operator token.

pub fn operator(&self) -> Option<PredicateOp>

Returns the operator kind.

pub fn string_value(&self) -> Option<SyntaxToken>

Returns the string value if the predicate uses a string.

pub fn regex(&self) -> Option<RegexLiteral>

Returns the regex literal if the predicate uses a regex.

pub fn value<'q>(&self, source: &'q str) -> Option<PredicateValue<'q>>

Returns the predicate value (string or regex pattern).