Module refs

Module refs 

Utilities for working with definition references in expressions.

Functions

contains_ref
Check if expression contains a reference to the given name.
ref_names
Collect all reference names as owned strings.
ref_nodes
Iterate over all Ref nodes in an expression tree.