pub struct Interner { /* private fields */ }Expand description
String interner. Deduplicates strings and returns cheap Symbol handles.
Implementations
Sourceimpl Interner
impl Interner
pub fn new() -> Interner
Sourcepub fn intern(&mut self, s: &str) -> Symbol
pub fn intern(&mut self, s: &str) -> Symbol
Intern a string, returning its Symbol. If the string was already interned, returns the existing Symbol.
Sourcepub fn intern_owned(&mut self, s: String) -> Symbol
pub fn intern_owned(&mut self, s: String) -> Symbol
Intern an owned string, avoiding clone if not already present.
Sourcepub fn try_resolve(&self, sym: Symbol) -> Option<&str>
pub fn try_resolve(&self, sym: Symbol) -> Option<&str>
Try to resolve a Symbol, returning None if invalid.