pub struct NodePredicate(/* private fields */);Implementations
Sourceimpl NodePredicate
impl NodePredicate
pub fn cast(node: SyntaxNode) -> Option<Self>
pub fn can_cast(kind: SyntaxKind) -> bool
pub fn as_cst(&self) -> &SyntaxNode
pub fn text_range(&self) -> TextRange
Sourceimpl NodePredicate
impl NodePredicate
Sourcepub fn operator_token(&self) -> Option<SyntaxToken>
pub fn operator_token(&self) -> Option<SyntaxToken>
Returns the operator token.
Sourcepub fn operator(&self) -> Option<PredicateOp>
pub fn operator(&self) -> Option<PredicateOp>
Returns the operator kind.
Sourcepub fn string_value(&self) -> Option<SyntaxToken>
pub fn string_value(&self) -> Option<SyntaxToken>
Returns the string value if the predicate uses a string.
Sourcepub fn regex(&self) -> Option<RegexLiteral>
pub fn regex(&self) -> Option<RegexLiteral>
Returns the regex literal if the predicate uses a regex.
Sourcepub fn value<'q>(&self, source: &'q str) -> Option<PredicateValue<'q>>
pub fn value<'q>(&self, source: &'q str) -> Option<PredicateValue<'q>>
Returns the predicate value (string or regex pattern).